@@ -21,6 +21,13 @@
 #include <GeoIP.h>
 #include <GeoIPCity.h>
 #include <GeoIP_internal.h>
+
+#if defined(_WIN32)
+# ifndef uint32_t 
+typedef unsigned int uint32_t; 
+# endif 
+#endif 
+
 void geoiplookup(GeoIP* gi,char *hostname,int i);
 
 void usage() {
@@ -64,7 +71,7 @@ int main (int argc, char *argv[]) {
 		exit(1);
 	}
 
-	if (custom_file != NULL) {
+	if (custom_directory != NULL) {
 		GeoIP_setup_custom_directory(custom_directory);
 	}
 	_GeoIP_setup_dbfilename();
@@ -108,6 +115,10 @@ int main (int argc, char *argv[]) {
 	return 0;
 }
 
+static const char * _mk_NA( const char * p ){
+ return p ? p : "N/A";
+}
+
 void
 geoiplookup(GeoIP * gi, char *hostname, int i)
 {
@@ -164,8 +175,8 @@ geoiplookup(GeoIP * gi, char *hostname, int i)
 				printf("%s: IP Address not found\n", GeoIPDBDescription[i]);
 			}
 			else {
-				printf("%s: %s, %s, %s, %s, %f, %f\n", GeoIPDBDescription[i], gir->country_code, gir->region,
-				       gir->city, gir->postal_code, gir->latitude, gir->longitude);
+				printf("%s: %s, %s, %s, %s, %f, %f\n", GeoIPDBDescription[i], gir->country_code, _mk_NA(gir->region),
+				       _mk_NA(gir->city), _mk_NA(gir->postal_code), gir->latitude, gir->longitude);
 			}
 		}
 		else if (GEOIP_CITY_EDITION_REV1 == i) {
@@ -174,7 +185,7 @@ geoiplookup(GeoIP * gi, char *hostname, int i)
 				printf("%s: IP Address not found\n", GeoIPDBDescription[i]);
 			}
 			else {
-				printf("%s: %s, %s, %s, %s, %f, %f, %d, %d\n", GeoIPDBDescription[i], gir->country_code, gir->region, gir->city, gir->postal_code,
+				printf("%s: %s, %s, %s, %s, %f, %f, %d, %d\n", GeoIPDBDescription[i], gir->country_code, _mk_NA(gir->region), _mk_NA(gir->city), _mk_NA(gir->postal_code),
 				       gir->latitude, gir->longitude, gir->metro_code, gir->area_code);
 			}
 		}
