@@ -25,6 +25,9 @@
 extern "C" {
 #endif
 
+#include <stdarg.h>
+#include <stdio.h>
+
 typedef enum {
 	GEOIP_NO_NEW_UPDATES          = 1,   /* Database up-to-date, no action taken */
   GEOIP_SUCCESS                 = 0,   /* Success */
@@ -50,10 +53,14 @@ typedef enum {
 const char * GeoIP_get_error_message(int i);
 
 /* Original Update Function, just for MaxMind GeoIP Country database */
-short int GeoIP_update_database (char * license_key, int verbose, void (*f)( char *));
+	short int GeoIP_update_database (char * license_key, int verbose, void (*f)( char *));
 
 /* More generalized update function that works more databases */
-short int GeoIP_update_database_general (char * user_id, char * license_key,char * data_base_type, int verbose,char ** client_ipaddr, void (*f)( char *));
+	short int GeoIP_update_database_general (char * user_id, char * license_key,char * data_base_type, int verbose,char ** client_ipaddr, void (*f)( char *));
+
+	/* experimental export */
+	int  GeoIP_fprintf(int (*f)(FILE *, char *),FILE *fp, const char *fmt, ...);
+	void GeoIP_printf(void (*f)(char *), const char *fmt, ...);
 
 #ifdef __cplusplus
 }
